@@ -103,26 +103,13 @@ bacon_video_widget_properties_time_to_string (int time)
 	time = time - (min * 60);
 	hour = time / (60*60);
 
-	if (hour == 1)
-		/* One hour */
-		hours = g_strdup_printf (_("%d hour"), hour);
-	else
-		/* Multiple hours */
-		hours = g_strdup_printf (_("%d hours"), hour);
+	hours = g_strdup_printf (ngettext ("%d hour", "%d hours", hour), hour);
 
-	if (min == 1)
-		/* One minute */
-		mins = g_strdup_printf (_("%d minute"), min);
-	else
-		/* Multiple minutes */
-		mins = g_strdup_printf (_("%d minutes"), min);
+	mins = g_strdup_printf (ngettext ("%d minute",
+					  "%d minutes", min), min);
 
-	if (sec == 1)
-		/* One second */
-		secs = g_strdup_printf (_("%d second"), sec);
-	else
-		/* Multiple seconds */
-		secs = g_strdup_printf (_("%d seconds"), sec);
+	secs = g_strdup_printf (ngettext ("%d second",
+					  "%d seconds", sec), sec);
 
 	if (hour > 0)
 	{
@@ -335,6 +322,7 @@ bacon_video_widget_properties_new (void)
 	props->priv->vbox = glade_xml_get_widget (props->priv->xml, "vbox1");
 
 	gtk_window_set_title (GTK_WINDOW (props), _("Properties"));
+	gtk_dialog_set_has_separator (GTK_DIALOG (props), FALSE);
 	gtk_dialog_add_buttons (GTK_DIALOG (props),
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
